Telemetry

Enum Telemetry 

pub enum Telemetry {
    Prometheus {
        prometheus_addr: SocketAddr,
        global_labels: HashMap<String, String>,
    },
    Log {
        path: PathBuf,
        global_labels: HashMap<String, String>,
    },
}
Defines the manner of lading’s telemetry.

Variants



Prometheus

In prometheus mode lading will emit its internal telemetry for scraping at a prometheus poll endpoint.

Fields

prometheus_addr: SocketAddr

Address and port for prometheus exporter

global_labels: HashMap<String, String>

Additional labels to include in every metric



Log

In log mode lading will emit its internal telemetry to a structured log file, the “capture” file.

Fields

path: PathBuf

Location on disk to write captures

global_labels: HashMap<String, String>

Additional labels to include in every metric