pub enum Server {
Tcp(Tcp),
Udp(Udp),
Http(Http),
SplunkHec(SplunkHec),
FileGen(FileGen),
FileTree(FileTree),
Grpc(Grpc),
UnixStream(UnixStream),
UnixDatagram(UnixDatagram),
ProcessTree(ProcessTree),
}Expand description
The generator server.
All generators supported by lading are a variant of this enum. Please see variant documentation for details.
Variants
Tcp(Tcp)
See crate::generator::tcp::Tcp for details.
Udp(Udp)
See crate::generator::udp::Udp for details.
Http(Http)
See crate::generator::http::Http for details.
SplunkHec(SplunkHec)
See crate::generator::splunk_hec::SplunkHec for details.
FileGen(FileGen)
See crate::generator::file_gen::FileGen for details.
FileTree(FileTree)
See crate::generator::file_tree::FileTree for details.
Grpc(Grpc)
See crate::generator::grpc::Grpc for details.
UnixStream(UnixStream)
See crate::generator::unix_stream::UnixStream for details.
UnixDatagram(UnixDatagram)
See crate::generator::unix_datagram::UnixDatagram for details.
ProcessTree(ProcessTree)
See crate::generator::process_tree::ProcessTree for details.
Implementations
Sourceimpl Server
impl Server
Sourcepub async fn run(self, pid_snd: TargetPidReceiver) -> Result<(), Error>
pub async fn run(self, pid_snd: TargetPidReceiver) -> Result<(), Error>
Run this Server to completion
This function runs the sub-server its completion, or until a shutdown
signal is received. Target server will transmit its pid via pid_snd
once the sub-process has started. This server will only begin once that
PID is sent, implying that the target is online.
Errors
Function will return an error if the underlying sub-server signals error.