Udp

Struct Udp 

pub struct Udp { /* private fields */ }
The UDP generator.

This generator is responsible for sending data to the target via UDP

Implementations

Source

impl Udp

pub fn new( general: General, config: &Config, shutdown: Shutdown, ) -> Result<Self, Error>

Create a new Udp instance

Errors

Creation will fail if the underlying governor capacity exceeds u32.

Panics

Function will panic if user has passed zero values for any byte values. Sharp corners.

pub async fn spin(self) -> Result<(), Error>

Run Udp to completion or until a shutdown signal is received.

Errors

Function will return an error when the UDP socket cannot be written to.

Panics

Function will panic if underlying byte capacity is not available.