pub enum Telemetry {
Prometheus {
prometheus_addr: SocketAddr,
global_labels: HashMap<String, String>,
},
Log {
path: PathBuf,
global_labels: HashMap<String, String>,
},
}Expand description
Defines the manner of lading’s telemetry.
Variants
Prometheus
In prometheus mode lading will emit its internal telemetry for scraping at a prometheus poll endpoint.
Fields

prometheus_addr: SocketAddrAddress and port for prometheus exporter
Log
In log mode lading will emit its internal telemetry to a structured log file, the “capture” file.